==> glpi-10.0.17.tgz: glpi/src/AllAssets.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2024 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

class AllAssets extends CommonGLPI
{
    public static function canView()
    {
        return Session::getCurrentInterface() == "central";
    }

    public static function getTypeName($nb = 0)
    {
        return _n('Asset', 'Assets', $nb);
    }

    public static function getIcon()
    {
        return 'ti ti-packages';
    }
}

==> glpi-11.0.2.tgz: glpi/src/AllAssets.php <==
<?php

/**
 * ---------------------------------------------------------------------
 *
 * GLPI - Gestionnaire Libre de Parc Informatique
 *
 * http://glpi-project.org
 *
 * @copyright 2015-2025 Teclib' and contributors.
 * @copyright 2003-2014 by the INDEPNET Development Team.
 * @licence   https://www.gnu.org/licenses/gpl-3.0.html
 *
 * ---------------------------------------------------------------------
 *
 * LICENSE
 *
 * This file is part of GLPI.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <https://www.gnu.org/licenses/>.
 *
 * ---------------------------------------------------------------------
 */

class AllAssets extends CommonGLPI
{
    public static function canView(): bool
    {
        return Session::getCurrentInterface() == "central";
    }

    public static function getHeaderParameters(): array
    {
        return [
            __('Global'),
            '',
            ...static::getSectorizedDetails(),
        ];
    }

    public static function getSectorizedDetails(): array
    {
        return ['assets', self::class];
    }

    public static function getTypeName($nb = 0)
    {
        return _n('Asset', 'Assets', $nb);
    }

    public static function getIcon()
    {
        return 'ti ti-packages';
    }
}
